@@ -1,3 +1,11 @@
+#pca is just an alias for the principal function
+
+"pca" <- function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,scores=TRUE,missing=FALSE,impute="median",oblique.scores=TRUE,method="regression",...) {
+   principal(r=r,nfactors=nfactors,residuals=residuals,rotate=rotate,n.obs=n.obs,covar=covar,scores=scores, missing=missing, impute=impute,oblique.scores=oblique.scores, method=method,...)
+
+}
+
+#to make principal components more similar in output to normal pca  in other systems.
 "principal" <-
 function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,scores=TRUE,missing=FALSE,impute="median",oblique.scores=TRUE,method="regression",...) {
    cl <- match.call()
@@ -72,32 +80,32 @@ if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentl
 Phi <- NULL 
  colnames(loadings) <- paste("RC",1:nfactors,sep='')   #for rotated component
 switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psych
-  varimax = {rotated <- stats::varimax(loadings)  #varimax is from stats, the others are from GPArotation 
+  varimax = {rotated <- stats::varimax(loadings,...)  #varimax is from stats, the others are from GPArotation 
    			         loadings <- rotated$loadings
    			         rot.mat <- rotated$rotmat},
    Varimax = {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	       #varimax is from the stats package, Varimax is from GPArotations
    			#rotated <- do.call(rotate,list(loadings,...))
    			#rotated <- do.call(getFromNamespace(rotate,'GPArotation'),list(loadings,...))
-   			rotated <- GPArotation::Varimax(loadings)
+   			rotated <- GPArotation::Varimax(loadings,...)
    			loadings <- rotated$loadings
    			 rot.mat <- t(solve(rotated$Th))} ,
    	quartimax = {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	      
    			#rotated <- do.call(rotate,list(loadings))
-   			rotated <- GPArotation::quartimax(loadings)
+   			rotated <- GPArotation::quartimax(loadings,...)
    			loadings <- rotated$loadings
    			 rot.mat <- t(solve(rotated$Th))} ,
    	bentlerT =  {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	       
    			#rotated <- do.call(rotate,list(loadings,...))
-   			rotated <- GPArotation::bentlerT(loadings)
+   			rotated <- GPArotation::bentlerT(loadings,...)
    			loadings <- rotated$loadings
    			 rot.mat <- t(solve(rotated$Th))} ,
    	geominT	= {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	      
    			#rotated <- do.call(rotate,list(loadings,...))
-   			rotated <- GPArotation::geominT(loadings)
+   			rotated <- GPArotation::geominT(loadings,...)
    			loadings <- rotated$loadings
    			 rot.mat <- t(solve(rotated$Th))} ,
    	targetT = {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
@@ -105,37 +113,37 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
    			loadings <- rotated$loadings
    			 rot.mat <- t(solve(rotated$Th))} ,
    			
-   	 bifactor = {rot <- bifactor(loadings)
+   	 bifactor = {rot <- bifactor(loadings,...)
    	             loadings <- rot$loadings
    	            rot.mat <- t(solve(rot$Th))},  
    	 TargetT =  {if (!requireNamespace('GPArotation')) {stop("I am sorry, to do this rotation requires the GPArotation package to be installed")}
    	            rot <- GPArotation::targetT(loadings,Tmat=diag(ncol(loadings)),...)
    	              loadings <- rot$loadings
    	            rot.mat <- t(solve(rot$Th))},
-   	equamax =  {rot <- equamax(loadings)
+   	equamax =  {rot <- equamax(loadings,...)
    	              loadings <- rot$loadings
    	            rot.mat <- t(solve(rot$Th))}, 
-   	varimin = {rot <- varimin(loadings)
+   	varimin = {rot <- varimin(loadings,...)
    	            loadings <- rot$loadings
    	            rot.mat <- t(solve(rot$Th))},
-   	specialT =  {rot <- specialT(loadings)
+   	specialT =  {rot <- specialT(loadings,...)
    	              loadings <- rot$loadings
    	              rot.mat <- t(solve(rot$Th))}, 
-   	Promax =   {pro <- Promax(loadings)
+   	Promax =   {pro <- Promax(loadings,...)
      			loadings <- pro$loadings
      			 Phi <- pro$Phi 
      			 rot.mat <- pro$rotmat},
-     promax =   {pro <- stats::promax(loadings)   #from stats
+     promax =   {pro <- stats::promax(loadings,...)   #from stats
      			 loadings <- pro$loadings
      			  rot.mat <- pro$rotmat
      			  ui <- solve(rot.mat)
      			  Phi <-  cov2cor(ui %*% t(ui))},	
-     cluster = 	 {loadings <- varimax(loadings)$loadings           			
+     cluster = 	 {loadings <- varimax(loadings,...)$loadings           			
 								pro <- target.rot(loadings)
      			              	loadings <- pro$loadings
      			                Phi <- pro$Phi
      			                 rot.mat <- pro$rotmat},
-     biquartimin =    {ob <- biquartimin(loadings,)
+     biquartimin =    {ob <- biquartimin(loadings,...)
                     loadings <- ob$loadings
      				 Phi <- ob$Phi
      				 rot.mat <- t(solve(ob$Th))}, 
@@ -246,4 +254,6 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
   #modified February 25, 2013 to make scores=TRUE the default 
   #modified 1/16/14 to output the structure matrix 
   #modified 8/15 to add rot.mat to all rotations
-  #modified 9/3/15 to label rotated PCs as RC  and transformed as TC -- perhaps this was dropped out while fixing rotations?
\ No newline at end of file
+  #modified 9/3/15 to label rotated PCs as RC  and transformed as TC -- perhaps this was dropped out while fixing rotations?
+  #added the pca function as an alias to principal 6/8/16
+  
\ No newline at end of file
